%define anolis_release 2

Name:           jsoncpp
Version:        1.9.5
Release:        %{anolis_release}%{?dist}
Summary:        JSON library implemented in C++
License:        Public Domain or MIT
URL:            https://github.com/open-source-parsers/%{name}
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake >= 3.1 gcc gcc-c++ python3-devel

%description
JSON is a lightweight data-interchange format. It can represent numbers,
strings, ordered sequences of values, and collections of name/value pairs.

JsonCpp is a C++ library that allows manipulating JSON values, including
serialization and deserialization to and from strings. It can also preserve
existing comment in unserialization/serialization steps, making it a
convenient format to store user input files.

%package        devel
Summary:        Development headers and library for %{name}
Requires:       %{name} = %{EVR}

%description    devel
This package contains the development headers and library for %{name}.

%package        doc
Summary:        Documentation for %{name}
BuildRequires:  doxygen graphviz hardlink
BuildArch:      noarch

%description    doc
This package contains the documentation for %{name}.

%prep
%autosetup
doxygen -s -u doc/doxyfile.in
sed -i -e 's!^DOT_FONTNAME.*=.*!DOT_FONTNAME =!g' doc/doxyfile.in

%build
%cmake                                         \
  -DBUILD_STATIC_LIBS:BOOL=OFF                 \
  -DBUILD_OBJECT_LIBS:BOOL=OFF                 \
  -DJSONCPP_WITH_CMAKE_PACKAGE:BOOL=ON         \
  -DJSONCPP_WITH_EXAMPLE:BOOL=OFF              \
  -DJSONCPP_WITH_PKGCONFIG_SUPPORT:BOOL=ON     \
  -DJSONCPP_WITH_POST_BUILD_UNITTEST:BOOL=OFF  \
  -DJSONCPP_WITH_STRICT_ISO:BOOL=ON            \
  -DJSONCPP_WITH_TESTS:BOOL=ON                 \
  -DJSONCPP_WITH_WARNING_AS_ERROR:BOOL=OFF     \
  -DPYTHON_EXECUTABLE:STRING="%{__python3}"
%cmake_build

cp -p %{__cmake_builddir}/version .
%{__python3} doxybuild.py --with-dot --doxygen %{_bindir}/doxygen
rm -f version

%install
%cmake_install

mkdir -p %{buildroot}%{_docdir}/%{name}
install -pm 0644 README.md %{buildroot}%{_docdir}/%{name}

mkdir -p %{buildroot}%{_docdir}/%{name}/html
cp -a dist/doxygen/jsoncpp-api-html-/* %{buildroot}%{_docdir}/%{name}/html

find %{buildroot}%{_docdir} -type d -print0 | xargs -0 chmod -c 0755
find %{buildroot}%{_docdir} -type f -print0 | xargs -0 chmod -c 0644
hardlink -cfv %{buildroot}%{_docdir}/%{name}

%generate_compatibility_deps

%check
%global _smp_mflags -j1
%ctest

%files
%{_libdir}/libjsoncpp.so.1.9.5
%{_libdir}/libjsoncpp.so.25
%dir %{abidir}
%{abidir}/libjsoncpp.dump

%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README.md
%exclude %{_docdir}/%{name}/html
%license AUTHORS LICENSE

%files devel
%{_libdir}/libjsoncpp.so
%{_includedir}/json
%{_libdir}/cmake/*
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%license %{_datadir}/licenses/%{name}
%doc %{_docdir}/%{name}

%changelog
* Thu Dec 14 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.9.5-2
- rebuild

* Fri May 12 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.9.5-1
- Init from upstream
